collision = require 'collision'

function love.load()
	if not love.filesystem.exists('maps') then
		love.filesystem.mkdir('maps')
	end
	help = {}
	help.bg   = love.image.newImageData(love.graphics.getWidth()/2, love.graphics.getHeight()/2)
	help.bg:mapPixel(function() return 0,0,0,128 end)
	help.bg = love.graphics.newImage(help.bg)
	help.text = love.filesystem.read('readme.txt')
	help.draw = function()
		love.graphics.draw(help.bg, 0, 0)
		love.graphics.draw(help.bg, 512, 0)
		love.graphics.draw(help.bg, 0, 384)
		love.graphics.draw(help.bg, 512, 384)
		love.graphics.printf(help.text, 128, 128, 768)
end
	maps = love.filesystem.enumerate('maps')
	ground = love.graphics.getHeight() - 160
	objects = {ground = {x = 0, y = ground, w = love.graphics.getWidth(), h = 160, hp = math.huge, m = math.huge, b = 1}}
	gui = {
		w  = 50,
		h  = 50,
		hp = 100,
		m  = 10,
		b  = 0.2,
		focus = 'w'}
	love.graphics.setLine(4, 'smooth')
	
	font = {
		default = love.graphics.newFont(12),
		huge    = love.graphics.newFont(32)}
end

function love.update(dt)

end

function love.draw()
	local width = love.graphics.getWidth()
	local x, y = love.mouse.getPosition()
	love.graphics.setColor(100, 50, 0)
	love.graphics.line(-4, ground, width+4, ground)
	love.graphics.setColor(255, 255, 255)
	love.graphics.print('Width:  ' .. gui.w, 0, 768)
	love.graphics.print('Height: ' .. gui.h, width*0.2, 768)
	love.graphics.print('Health: ' .. gui.hp, width*0.4, 768)
	love.graphics.print('Mass: ' .. gui.m, width*0.6, 768)
	love.graphics.print('Bounciness: ' .. gui.b, width*0.8, 768)
	love.graphics.setColor(255,0,0)
	love.graphics.setFont(font.huge)
	love.graphics.printf(gui.focus, 0, 769, love.graphics.getWidth(), 'right')
	love.graphics.setFont(font.default)
	love.graphics.setColor(255,255,255)
	for i, v in ipairs(objects) do
		love.graphics.rectangle('line', v.x, v.y, v.w, v.h)
	end
	for i = 1,9 do
		if love.filesystem.exists('maps/map'..i..'.lua') then
			love.graphics.setColor(255,255,255)
		else
			love.graphics.setColor(128,128,128)
		end
		love.graphics.print('map'..i..'.lua', width*(i-1)/9, 784)
	end	
	if y < 769 then
		love.graphics.rectangle('line', x, y, gui.w, gui.h)
	end
	if love.keyboard.isDown('f1', 'h') then
		help.draw()
	end
end

function love.mousepressed(x, y, b)
	if b == 'l' and y < 769 then
		colliding = collision.checkInsert(x, y)
		if not colliding then
			table.insert(objects, {x = x, y = y, w = gui.w, h = gui.h, hp = gui.hp, m = gui.m, b = gui.b})
		end
	end
	if b == 'r' then
		collision.Remove(x, y)
	end
	if b == 'l' and y >= 769 then
		if x < love.graphics.getWidth()*0.2 then
			gui.focus = 'w'
		elseif x < love.graphics.getWidth()*0.4 then
			gui.focus = 'h'
		elseif x < love.graphics.getWidth()*0.6 then
			gui.focus = 'hp'
		elseif x < love.graphics.getWidth()*0.8 then
			gui.focus = 'm'
		else
			gui.focus = 'b'
		end
	end
end

function love.keypressed(k, u)
	if k == 'left' then
		gui[gui.focus] = gui[gui.focus] - 10
	end
	if k == 'right' then
		gui[gui.focus] = gui[gui.focus] + 10
	end
	if k == 'up' then
		gui[gui.focus] = gui[gui.focus] + 1
	end
	if k == 'down' then
		gui[gui.focus] = gui[gui.focus] - 1
	end
	if k == 'return' then
		local f = love.filesystem.newFile('maps/map'..#maps+1 .. '.lua')
		f:open('w')
		for i,v in ipairs(objects) do
			f:write('enemy(' .. v.x+v.w .. ', ' .. v.y+v.h .. ', ' .. v.w .. ', ' .. v.h .. ', ' .. v.hp .. ', ' .. v.m .. ', ' .. v.b .. ')\n')
		end
	end
	if tonumber(k) and love.keyboard.isDown('o') then
		love.filesystem.remove('maps/map'..k..'.lua')
	end
	if tonumber(k) ~= 0 and not love.filesystem.exists('maps/map'..k..'.lua') then
		local f = love.filesystem.newFile('maps/map'..k..'.lua')
		f:open('w')
		for i,v in ipairs(objects) do
			f:write('enemy(' .. v.x .. ', ' .. v.y+v.h .. ', ' .. v.w .. ', ' .. v.h .. ', ' .. v.hp .. ', ' .. v.m .. ', ' .. v.b .. ')\n')
		end
		f:close()
	end
	if tonumber(k) and (love.keyboard.isDown('backspace') or love.keyboard.isDown('delete'))then
		love.filesystem.remove('maps/map'..k..'.lua')
	end
end